@@ -2,13 +2,13 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-0.8-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-0.8-`date +%Y%m%d`.zip
-cd /opt/gnome2
+ZIP=/tmp/atk-0.9-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-0.9-`date +%Y%m%d`.zip
+cd /opt/gnome-2.0
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
-lib/libatk-8.dll
+lib/libatk-9.dll
 EOF
 
 rm $DEVZIP
